# Generated by roxygen2: do not edit by hand

S3method(as.ts,cat_sim)
S3method(as.ts,gau_sim)
S3method(as.ts,inad_sim)
S3method(coef,cat_fit)
S3method(coef,gau_fit)
S3method(coef,inad_fit)
S3method(confint,cat_fit)
S3method(confint,gau_fit)
S3method(confint,inad_fit)
S3method(deviance,cat_fit)
S3method(deviance,gau_fit)
S3method(deviance,inad_fit)
S3method(fitted,gau_fit)
S3method(logLik,cat_fit)
S3method(logLik,gau_fit)
S3method(logLik,inad_fit)
S3method(nobs,cat_fit)
S3method(nobs,gau_fit)
S3method(nobs,inad_fit)
S3method(plot,cat_fit)
S3method(plot,gau_fit)
S3method(plot,inad_fit)
S3method(plot,partial_corr)
S3method(print,bic_order_inad)
S3method(print,cat_ci)
S3method(print,cat_fit)
S3method(print,cat_lrt)
S3method(print,gau_bic_order)
S3method(print,gau_ci)
S3method(print,gau_contrast_test)
S3method(print,gau_fit)
S3method(print,gau_homogeneity_test)
S3method(print,gau_mean_test)
S3method(print,gau_order_test)
S3method(print,homogeneity_tests_inad)
S3method(print,inad_ci)
S3method(print,inad_fit)
S3method(print,partial_corr)
S3method(print,stationarity_tests_gau)
S3method(print,stationarity_tests_inad)
S3method(print,test_homogeneity_inad)
S3method(print,test_order_inad)
S3method(print,test_stationarity_gau)
S3method(print,test_stationarity_inad)
S3method(residuals,gau_fit)
S3method(vcov,gau_fit)
S3method(summary,cat_ci)
S3method(summary,cat_fit)
S3method(summary,gau_ci)
S3method(summary,gau_fit)
S3method(summary,inad_ci)
S3method(summary,inad_fit)
S3method(summary,partial_corr)
export(aic_cat)
export(aic_gau)
export(aic_inad)
export(bic_cat)
export(bic_gau)
export(bic_inad)
export(bic_order_cat)
export(bic_order_gau)
export(bic_order_inad)
export(ci_cat)
export(ci_gau)
export(ci_inad)
export(dbell)
export(em_cat)
export(em_gau)
export(em_inad)
export(fit_cat)
export(fit_gau)
export(fit_inad)
export(logL_cat)
export(logL_gau)
export(logL_inad)
export(logL_inad_i)
export(partial_corr)
export(pbell)
export(plot_prism)
export(plot_profile)
export(qbell)
export(rbell)
export(run_homogeneity_tests_inad)
export(run_order_tests_cat)
export(run_stationarity_tests_cat)
export(run_stationarity_tests_gau)
export(run_stationarity_tests_inad)
export(simulate_cat)
export(simulate_gau)
export(simulate_inad)
export(test_contrast_gau)
export(test_homogeneity_cat)
export(test_homogeneity_gau)
export(test_homogeneity_inad)
export(test_one_sample_gau)
export(test_order_cat)
export(test_order_gau)
export(test_order_inad)
export(test_stationarity_cat)
export(test_stationarity_gau)
export(test_stationarity_inad)
export(test_timeinvariance_cat)
export(test_two_sample_gau)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(stats,as.ts)
importFrom(stats,complete.cases)
importFrom(stats,confint)
importFrom(stats,deviance)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dbinom)
importFrom(stats,dnbinom)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,fitted)
importFrom(stats,logLik)
importFrom(stats,lm)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,rmultinom)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(stats,vcov)
