% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ci_inad.R
\name{.poster_general}
\alias{.poster_general}
\title{Posterior computations for all thinning-innovation combinations}
\usage{
.poster_general(m, n, alpha, lambda, thinning, innovation, nb_inno_size = NULL)
}
\description{
Computes conditional expectations and variances needed for Louis' identity.
See Appendix C of the paper for the derivation.
}
\keyword{internal}
