% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cat_utils.R
\name{.loglik_contribution}
\alias{.loglik_contribution}
\title{Compute log-likelihood contribution from counts and probabilities}
\usage{
.loglik_contribution(counts, probs)
}
\arguments{
\item{counts}{Array of counts}

\item{probs}{Array of probabilities (same dimensions as counts)}
}
\value{
Scalar log-likelihood contribution
}
\description{
Computes sum of N * log(pi) over all cells.
}
\keyword{internal}
