% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inad_utils.R
\name{.log_sum_exp}
\alias{.log_sum_exp}
\title{Log-sum-exp for numerical stability}
\usage{
.log_sum_exp(x)
}
\description{
Log-sum-exp for numerical stability
}
\keyword{internal}
