% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lrt_order_gau.R
\name{bic_order_gau}
\alias{bic_order_gau}
\title{BIC-based order selection for Gaussian AD models}
\usage{
bic_order_gau(y, max_order = 2L, ...)
}
\arguments{
\item{y}{Numeric matrix with n_subjects rows and n_time columns.}

\item{max_order}{Maximum order to consider.}

\item{...}{Additional arguments passed to \code{\link{fit_gau}}.}
}
\value{
A list with class \code{gau_bic_order} containing:
\describe{
\item{fits}{List of fitted models}
\item{bic}{BIC values for each order}
\item{best_order}{Order with lowest BIC}
\item{table}{Summary table}
}
}
\description{
Fits AD models of increasing orders and selects the best by BIC.
}
\examples{
\donttest{
set.seed(1)
y <- simulate_gau(n_subjects = 80, n_time = 6, order = 1, phi = 0.4)
ord <- bic_order_gau(y, max_order = 2)
ord$best_order
ord$table
}

}
\seealso{
\code{\link{bic_order_cat}}, \code{\link{bic_order_inad}},
\code{\link{fit_gau}}
}
