% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cat_utils.R
\name{.counts_to_transition_probs}
\alias{.counts_to_transition_probs}
\title{Compute transition probabilities from counts (simpler version)}
\usage{
.counts_to_transition_probs(counts)
}
\arguments{
\item{counts}{Array of counts, last dimension is response}
}
\value{
Array of transition probabilities (same dimensions)
}
\description{
Given counts array with last dimension being Y_k and earlier dimensions
being conditioning variables, compute P(Y_k | conditioning).
}
\keyword{internal}
