% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loglik_inad.R
\name{.inad_conv_trunc}
\alias{.inad_conv_trunc}
\title{Truncated discrete convolution}
\usage{
.inad_conv_trunc(p, q, K)
}
\description{
Truncated discrete convolution
}
\keyword{internal}
