% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lrt_order_gau.R
\name{print.gau_bic_order}
\alias{print.gau_bic_order}
\title{Print method for BIC order selection}
\usage{
\method{print}{gau_bic_order}(x, ...)
}
\arguments{
\item{x}{Object of class \code{gau_bic_order}.}

\item{...}{Unused.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print method for BIC order selection
}
