% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inad_utils.R
\name{.inad_effective_innovation_param}
\alias{.inad_effective_innovation_param}
\title{Effective innovation distribution parameter under block effects}
\usage{
.inad_effective_innovation_param(theta, tau, innovation)
}
\description{
For Poisson and negative binomial innovations, block effects are additive on
the mean. For Bell innovations, block effects are additive on the innovation
mean \code{theta * exp(theta)}, then mapped back to the Bell parameter.
}
\keyword{internal}
