% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inad_utils.R
\name{.innov_vec}
\alias{.innov_vec}
\title{Innovation probability vector}
\usage{
.innov_vec(u_vals, lam, innovation, sz)
}
\arguments{
\item{u_vals}{Integer vector of possible innovation values.}

\item{lam}{Innovation parameter used by the PMF. This is the mean for
\code{"pois"} and \code{"nbinom"}, and the Bell parameter for \code{"bell"}.}

\item{innovation}{One of "pois", "bell", "nbinom".}

\item{sz}{Size parameter for negative binomial innovation (ignored otherwise).}
}
\value{
Numeric vector of probabilities.
}
\description{
Computes the probability mass for innovation counts.
}
\keyword{internal}
