% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lrt_stationarity_inad.R
\name{run_stationarity_tests_inad}
\alias{run_stationarity_tests_inad}
\title{Run all stationarity-related tests for INAD}
\usage{
run_stationarity_tests_inad(
  y,
  order = 1,
  thinning = "binom",
  innovation = "pois",
  blocks = NULL,
  verbose = FALSE,
  ...
)
}
\arguments{
\item{y}{Integer matrix.}

\item{order}{Model order (1 or 2).}

\item{thinning}{Thinning operator.}

\item{innovation}{Innovation distribution.}

\item{blocks}{Optional block assignments.}

\item{verbose}{Logical.}

\item{...}{Additional arguments.}
}
\value{
A list with class "stationarity_tests_inad".
}
\description{
Run all stationarity-related tests for INAD
}
\examples{
set.seed(1)
y <- simulate_inad(
  n_subjects = 25,
  n_time = 5,
  order = 1,
  thinning = "binom",
  innovation = "pois",
  alpha = 0.3,
  theta = 2
)
out <- run_stationarity_tests_inad(
  y,
  order = 1,
  thinning = "binom",
  innovation = "pois",
  verbose = FALSE,
  max_iter = 15
)
out$summary
}
