% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.prism_residuals}
\alias{.prism_residuals}
\title{Compute partial residuals for PRISM plot}
\usage{
.prism_residuals(y, i, j)
}
\arguments{
\item{y}{Data matrix (n_subjects x n_time).}

\item{i}{First time index.}

\item{j}{Second time index (j > i + 1).}
}
\value{
List with resid_i and resid_j (partial residuals).
}
\description{
Compute partial residuals for PRISM plot
}
\keyword{internal}
