% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cat_utils.R
\name{.history_to_index}
\alias{.history_to_index}
\title{Convert history to array index}
\usage{
.history_to_index(history, n_categories)
}
\arguments{
\item{history}{Integer vector of category values}

\item{n_categories}{Number of categories}
}
\value{
Integer index (1-based) into flattened array
}
\description{
Convert history to array index
}
\keyword{internal}
