% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lrt_stationarity_cat.R
\name{.fit_cat_stationary}
\alias{.fit_cat_stationary}
\title{Fit stationary categorical AD model}
\usage{
.fit_cat_stationary(y, p, c, blocks = NULL, homogeneous = TRUE)
}
\arguments{
\item{y}{Data matrix}

\item{p}{Order}

\item{c}{Number of categories}

\item{blocks}{Block vector (or NULL)}

\item{homogeneous}{Whether to pool across blocks}
}
\value{
A cat_fit-like object with stationary constraints
}
\description{
Internal function to fit a model where both marginal and transition
probabilities are constant over time.
}
\keyword{internal}
