% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inad_utils.R
\name{.unpack_alpha}
\alias{.unpack_alpha}
\title{Unpack alpha parameters}
\usage{
.unpack_alpha(order, alpha, N)
}
\arguments{
\item{order}{Model order (0, 1, or 2).}

\item{alpha}{Alpha parameter in various formats.}

\item{N}{Number of time points.}
}
\value{
List with elements a1 and a2.
}
\description{
Converts alpha from various input formats to a standardized list.
}
\keyword{internal}
