% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gau_utils.R
\name{.rss_vector_gau}
\alias{.rss_vector_gau}
\title{Compute RSS vector for all time points under AD(p)}
\usage{
.rss_vector_gau(y, p, mu = NULL)
}
\arguments{
\item{y}{Numeric matrix n_subjects by n_time.}

\item{p}{Antedependence order.}

\item{mu}{Optional mean vector for centering.}
}
\value{
Numeric vector of length n_time with RSS for each time point.
}
\description{
Compute RSS vector for all time points under AD(p)
}
\keyword{internal}
