% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_cat.R
\name{.cat_prob_to_theta}
\alias{.cat_prob_to_theta}
\title{Convert probability row to unconstrained logits}
\usage{
.cat_prob_to_theta(prob, c, eps = 1e-08)
}
\arguments{
\item{prob}{Probability vector of length c}

\item{c}{Number of categories}

\item{eps}{Lower bound for numerical stability}
}
\value{
Numeric vector of length c-1
}
\description{
Convert probability row to unconstrained logits
}
\keyword{internal}
