% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_gau_em.R
\name{.initialize_gau_marginal}
\alias{.initialize_gau_marginal}
\title{Initialize from marginal statistics (ignoring dependence)}
\usage{
.initialize_gau_marginal(y, order, blocks)
}
\description{
Initialize from marginal statistics (ignoring dependence)
}
\keyword{internal}
