% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cat_utils.R
\name{.counts_to_probs_cat}
\alias{.counts_to_probs_cat}
\title{Convert counts to probabilities (with safe division)}
\usage{
.counts_to_probs_cat(counts, margin = NULL)
}
\arguments{
\item{counts}{Array of counts}

\item{margin}{Which margins to condition on (sum over). NULL = no conditioning (joint).}
}
\value{
Array of probabilities
}
\description{
Convert counts to probabilities (with safe division)
}
\keyword{internal}
