% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inad_utils.R
\name{.thin_vec}
\alias{.thin_vec}
\title{Thinning probability vector}
\usage{
.thin_vec(k_vals, yprev, a, thinning)
}
\arguments{
\item{k_vals}{Integer vector of possible thinned values.}

\item{yprev}{Previous count (size parameter for thinning).}

\item{a}{Thinning parameter alpha.}

\item{thinning}{One of "binom", "pois", "nbinom".}
}
\value{
Numeric vector of probabilities.
}
\description{
Computes the probability mass for thinned counts.
}
\keyword{internal}
