% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gau_utils.R
\name{.mle_mean_gau}
\alias{.mle_mean_gau}
\title{Compute MLE of mean vector under AD(p)}
\usage{
.mle_mean_gau(y)
}
\arguments{
\item{y}{Numeric matrix n_subjects by n_time.}
}
\value{
Numeric vector of mean estimates.
}
\description{
Under AD(p), the MLE of mu is the sample mean vector when there are no
covariates.
}
\keyword{internal}
