% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_methods.R
\name{plot.partial_corr}
\alias{plot.partial_corr}
\title{Heatmap plot for a partial_corr object}
\usage{
\method{plot}{partial_corr}(x, ...)
}
\arguments{
\item{x}{A \code{partial_corr} object from \code{\link{partial_corr}}.}

\item{...}{Unused.}
}
\value{
\code{x}, invisibly.
}
\description{
Displays the partial correlation matrix as a colour heatmap using base
graphics.  Upper triangle shows ordinary correlations; lower triangle
shows intervenor-adjusted partial correlations; the diagonal shows
standardised variances.
}
\examples{
\donttest{
data("bolus_inad")
pc <- partial_corr(bolus_inad$y)
plot(pc)
}

}
